#include <unistd.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <slang.h>
#include <termios.h>

SLANG_MODULE(serial);

typedef struct
{
   char *device;
   unsigned int baudrate;
}
Serial_Port;

SLang_CStruct_Field_Type Serial_Port_Layout [] =
{
   MAKE_CSTRUCT_FIELD (Serial_Port, device, "device", SLANG_STRING_TYPE, 0),
   MAKE_CSTRUCT_FIELD (Serial_Port, baudrate, "baudrate", SLANG_UINT_TYPE, 0),
   SLANG_END_CSTRUCT_TABLE
};

int sp_open (int *n)
{
   int fd;
   char dev [15] = "/dev/ttyS";
   struct termios oldconf, newconf;
   Serial_Port port;
   port.device = "/dev/ttyS0";
   port.baudrate = 9600;
   /* port = malloc (sizeof (*port)); */
   /* strcpy (port->device, "hello"); */
   /* port->baudrate = 9600; */
   
   dev [9] = *n + 48;
   
   fd = open (dev, O_RDWR | O_NOCTTY);
   
   if (-1 != fd)
     fcntl (fd, F_SETFL, 0);
   
   /* tcgetattr (fd, &oldconf); */
   
   /* bzero (&newconf, sizeof (newconf)); */
   
   /* tcsetattr (fd, newconf); */
   
   /* return (port); */
   
   return SLang_push_cstruct ((VOID_STAR)&port, Serial_Port_Layout);
}

int sp_close (int *fd)
{
   return (close (*fd));
}

void sp_read (int *fd, int *n)
{
   unsigned char *buff;
   
   buff = SLmalloc (*n);
   
   if (-1 == read (*fd, buff, *n))
     (void) SLang_push_int (-1);
   else
     (void) SLang_push_string (buff);
}

void sp_readline (int *fd)
{
}

int sp_write (int *fd, char *str)
{
   return write (*fd, str, strlen (str));
}

int sp_in_waiting (int *fd)
{
   int bytes;
   
   if (-1 == ioctl (*fd, FIONREAD, &bytes))
     return -1;
   else
     return bytes;      
}

unsigned int sp_get_baudrate (int *fd)
{
   struct termios options;
   
   tcgetattr (*fd, &options);
   return cfgetispeed (&options);
}

int sp_set_baudrate (int *fd, int *baud)
{
   struct termios options;

   tcgetattr (*fd, &options);

   cfsetispeed (&options, *baud);
   cfsetospeed (&options, *baud);
   
   options.c_cflag |= (CLOCAL | CREAD);
   tcsetattr(*fd, TCSANOW, &options);
}

/* int sp_flush_input (*fd) */
/* { */
/* } */

/* int sp_flush_output (*fd) */
/* { */
/* } */

#define I SLANG_INT_TYPE
#define S SLANG_STRING_TYPE
#define UI SLANG_UINT_TYPE
#define V SLANG_VOID_TYPE

static SLang_Intrin_Fun_Type SLserial_Intrinsics [] =
{
   MAKE_INTRINSIC_1 ("sp_open", sp_open, I, I),
   MAKE_INTRINSIC_1 ("close", sp_close, I, I),
   MAKE_INTRINSIC_2 ("read", sp_read, V, I, I),
   MAKE_INTRINSIC_2 ("write", sp_write, I, I, S),
   MAKE_INTRINSIC_1 ("in_waiting", sp_in_waiting, I, I),
   MAKE_INTRINSIC_1 ("get_baudrate", sp_get_baudrate, UI, I),
   MAKE_INTRINSIC_2 ("set_baudrate", sp_set_baudrate, I, I, I),
   SLANG_END_INTRIN_FUN_TABLE
};

#undef I
#undef S
#undef UI
#undef V

int init_serial_module_ns (char *ns_name)
{   
   SLang_NameSpace_Type *ns;
   
   ns = SLns_create_namespace (ns_name);
   if (ns == NULL)
     return -1;
   
   if (-1 == SLns_add_intrin_fun_table (ns, SLserial_Intrinsics, "__SLSERIAL__"))
     return -1;
   
   return 0;
}
