\function{serial_open}
\synopsis{Open a serial port}
\usage{Serial_Type serial_open (port ; qualifiers)}
\description
The \ifun{serial_open} function open the serial port specified by the
port parameter.
#% \qualifiers

QUALIFIERS
The following qualifiers are supported by the function :
#v+
baudrate = int           Sets the baud rate.
bytesize = int           Number of data bits.
input_baudrate = int     Input baud rate.
output_baudrate = int    Output baud rate.
parity = string          Parity checking.
rtscts = int             Sets hardware control flow.
stopbits = int           Number of stop bits.
timeout = float          Timeout for reading data. If timeout < 0, blocks
                         until the requested number of bytes is read.                      
xonxoff = int            Sets software control flow.
write_timeout = float    Timeout for writing data.
#v-
\example
#v+
s = serial_open ("/dev/ttyUSB0" ; baudrate = 115200);
#v-
\seealso{serial_close}
\done

\function{serial_close}
\synopsis{Close a serial port}
\usage{serial_close (Serial_Type)}
\description
The \ifun{serial_close} function close an open serial port.
\seealso{serial_open}
\done

\function{serial_read}
\synopsis{Read bytes from a serial port}
\usage{BString_Type serial_read (serial_read (Serial_Type, [, n])}
\description
The \ifun{serial_read} function read \ifun{n} bytes (default : 1 byte) from the
serial port. 
\notes If timeout is set to a negative value, \ifun{serial_read will
block forever.
\seealso{serial_gets}
\done

\function{serial_gets}
\synopsis{Read a line from a serial port}
\usage{String_Type serial_gets (Serial_Type [, int])}
\description
The \ifun{serial_gets} function read an entire line from a serial port.
End of line character can be pass as an optional parameter and default
to LF (new line).
\seealso{serial_read, serial_getslines}
\done

\function{serial_getslines}
\synopsis{Read lines as a list from a serial port}
\usage{List_Type serial_getslines (Serial_Type [, int]}
\description
The \ifun{serial_getslines} function read multiple lines from a serial
port. End of line character can be pass as an optional parameter and
default to LF (new line).
\seealso{serial_read, serial_gets}
\done

\function{serial_write}
\synopsis{Write to a serial port}
\usage{serial_write (Serial_Type, BString_Type)}
\description
The \ifun{serial_write} function write data to a serial port.
\seealso{serial_write_lines}
\done

\function{serial_write_lines}
\synopsis{Write an array of lines to a serial port}
\usage{serial_write_lines (Serial_Type, String_Type [])}
\description
The \ifun{serial_write_lines} function write lines from a given array or
list to a serial port.
\seealso{serial_write}
\done

\function{flush_input}
\synopsis{Flush a serial port input buffer}
\usage{flush_input (Serial_Type)}
\description
The \ifun{flush_input} function remove all data from input buffer.
\seealso{flush_output}
\done

\function{flush_output}
\synopsis{Flush a serial port output buffer}
\usage{flush_output (Serial_Type)}
\description
The \ifun{flush_output} function remove all data from output buffer.
\seealso{flush_input}
\done

\function{serial_in_waiting}
\synopsis{Return the number of bytes waiting in the input buffer}
\usage{Integer_Type serial_in_waiting (Serial_Type)}
\description
The \ifun{serial_in_waiting} function may be used to know if data have
been received.
\seealso{serial_open, serial_read}
\done

\function{serial_send_break}
\synopsis{Send a break}
\usage{serial_send_break (Serial_Type, Integer_Type)}
\description
The \ifun{serial_send_break} function may be used to send a break.
\seealso{serial_open}
\done

\function{serial_set_rts}
\synopsis{Set RTS status line}
\usage{serial_set_rts (Serial_Type, Integer_Type)}
\description
The \ifun{serial_set_rts} function sets the request to send control
signal to the given status.
\seealso{serial_open, serial_get_cts}
\done

\function{serial_set_dtr}
\synopsis{Set DTR status line}
\usage{serial_set_dtr (Serial_Type, Integer_Type)}
\description
The \ifun{serial_set_dtr} function sets the data terminal ready control
signal to the given status.
\seealso{serial_open}
\done

\function{serial_get_cts}
\synopsis{Get CTS status line}
\usage{Integer_Type serial_get_cts (Serial_Type)}
\description
The \ifun{serial_get_cts} function gets the clear to send control
signal status.
\seealso{serial_open, serial_get_cts}
\done

\function{serial_get_dsr}
\synopsis{Get DSR status line}
\usage{Integer_Type serial_get_dsr (Serial_Type)}
\description
The \ifun{serial_get_dsr} function gets the data set ready control
signal status.
\seealso{serial_open}
\done

\function{serial_get_ri}
\synopsis{Get RI status line}
\usage{Integer_Type serial_get_ri (Serial_Type)}
\description
The \ifun{serial_get_ri} function gets the ring indicator control
signal status.
\seealso{serial_open}
\done

\function{serial_get_cd}
\synopsis{Get CD status line}
\usage{Integer_Type serial_get_cd (Serial_Type)}
\description
The \ifun{serial_get_cd} function gets the data carrier detect control
signal status.
\seealso{serial_open}
\done
